#[non_exhaustive]pub struct SignatureError { /* private fields */ }Expand description
Signature errors.
This type is deliberately opaque as to avoid sidechannel leakage which could potentially be used recover signing private keys or forge signatures (e.g. BB’06).
When the std feature is enabled, it impls
core::error::Error.
When the alloc feature is enabled, it supports an optional
core::error::Error::source,
which can be used by things like remote signers (e.g. HSM, KMS) to report
I/O or auth errors.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn from_source(source: impl Into<Box<dyn Error + Send + Sync>>) -> Error
Available on crate feature alloc only.
pub fn from_source(source: impl Into<Box<dyn Error + Send + Sync>>) -> Error
alloc only.Create a new error with an associated source.
NOTE: The “source” should NOT be used to propagate cryptographic errors e.g. signature parsing or verification errors. The intended use cases are for propagating errors related to external signers, e.g. communication/authentication errors with HSMs, KMS, etc.